CodeFormatter

Struct CodeFormatter 

pub struct CodeFormatter<'a, T> { /* private fields */ }
Helper struct for efficiently dedent and indent multi line display implementations

Explanation

This type allocates a string once to get the formatted result and then uses the internal formatter efficiently to: first dedent the output, then re-indent to the desired level.

Implementations

Source

impl<'a, T: Write> CodeFormatter<'a, T>

pub fn new<S: Into<String>>(f: &'a mut T, indentation: S) -> Self

Wrap the formatter f, use indentation as base string indentation and return a new formatter that implements std::fmt::Write that can be used with the macro write!()

pub fn set_level(&mut self, level: u32)

Set the indentation level to a specific value

pub fn indent(&mut self, inc: u32)

Increase the indentation level by inc

pub fn dedent(&mut self, inc: u32)

Decrease the indentation level by inc