pub struct CodeFormatter<'a, T> { /* private fields */ }Expand description
Helper struct for efficiently dedent and indent multi line display implementations
Explanation
This type allocates a string once to get the formatted result and then uses the internal formatter efficiently to: first dedent the output, then re-indent to the desired level.
Implementations